import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface HelmProviderConfig {
    /**
     * Debug indicates whether or not Helm is running in Debug mode.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#debug HelmProvider#debug}
     *
     * @stability stable
     */
    readonly debug?: boolean | cdktf.IResolvable;
    /**
     * The backend storage driver. Values are: configmap, secret, memory, sql.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#helm_driver HelmProvider#helm_driver}
     *
     * @stability stable
     */
    readonly helmDriver?: string;
    /**
     * The path to the helm plugins directory.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#plugins_path HelmProvider#plugins_path}
     *
     * @stability stable
     */
    readonly pluginsPath?: string;
    /**
     * The path to the registry config file.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#registry_config_path HelmProvider#registry_config_path}
     *
     * @stability stable
     */
    readonly registryConfigPath?: string;
    /**
     * The path to the file containing cached repository indexes.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#repository_cache HelmProvider#repository_cache}
     *
     * @stability stable
     */
    readonly repositoryCache?: string;
    /**
     * The path to the file containing repository names and URLs.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#repository_config_path HelmProvider#repository_config_path}
     *
     * @stability stable
     */
    readonly repositoryConfigPath?: string;
    /**
     * Alias name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#alias HelmProvider#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
    /**
     * experiments block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#experiments HelmProvider#experiments}
     *
     * @stability stable
     */
    readonly experiments?: HelmProviderExperiments;
    /**
     * kubernetes block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#kubernetes HelmProvider#kubernetes}
     *
     * @stability stable
     */
    readonly kubernetes?: HelmProviderKubernetes;
}
/**
 * @stability stable
 */
export interface HelmProviderExperiments {
    /**
     * Enable full diff by storing the rendered manifest in the state.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#manifest HelmProvider#manifest}
     *
     * @stability stable
     */
    readonly manifest?: boolean | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class HelmProviderExperimentsOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _manifest?;
    /**
     * @stability stable
     */
    get manifest(): boolean | cdktf.IResolvable | undefined | undefined;
    /**
     * @stability stable
     */
    set manifest(value: boolean | cdktf.IResolvable | undefined | undefined);
    /**
     * @stability stable
     */
    resetManifest(): void;
    /**
     * @stability stable
     */
    get manifestInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * @stability stable
 */
export interface HelmProviderKubernetesExec {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#api_version HelmProvider#api_version}.
     *
     * @stability stable
     */
    readonly apiVersion: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#args HelmProvider#args}.
     *
     * @stability stable
     */
    readonly args?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#command HelmProvider#command}.
     *
     * @stability stable
     */
    readonly command: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#env HelmProvider#env}.
     *
     * @stability stable
     */
    readonly env?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class HelmProviderKubernetesExecOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _apiVersion?;
    /**
     * @stability stable
     */
    get apiVersion(): string | undefined;
    /**
     * @stability stable
     */
    set apiVersion(value: string | undefined);
    /**
     * @stability stable
     */
    get apiVersionInput(): string | undefined;
    private _args?;
    /**
     * @stability stable
     */
    get args(): string[] | undefined | undefined;
    /**
     * @stability stable
     */
    set args(value: string[] | undefined | undefined);
    /**
     * @stability stable
     */
    resetArgs(): void;
    /**
     * @stability stable
     */
    get argsInput(): string[] | undefined;
    private _command?;
    /**
     * @stability stable
     */
    get command(): string | undefined;
    /**
     * @stability stable
     */
    set command(value: string | undefined);
    /**
     * @stability stable
     */
    get commandInput(): string | undefined;
    private _env?;
    /**
     * @stability stable
     */
    get env(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined | undefined;
    /**
     * @stability stable
     */
    set env(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined | undefined);
    /**
     * @stability stable
     */
    resetEnv(): void;
    /**
     * @stability stable
     */
    get envInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
}
/**
 * @stability stable
 */
export interface HelmProviderKubernetes {
    /**
     * PEM-encoded client certificate for TLS authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#client_certificate HelmProvider#client_certificate}
     *
     * @stability stable
     */
    readonly clientCertificate?: string;
    /**
     * PEM-encoded client certificate key for TLS authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#client_key HelmProvider#client_key}
     *
     * @stability stable
     */
    readonly clientKey?: string;
    /**
     * PEM-encoded root certificates bundle for TLS authentication.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#cluster_ca_certificate HelmProvider#cluster_ca_certificate}
     *
     * @stability stable
     */
    readonly clusterCaCertificate?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#config_context HelmProvider#config_context}.
     *
     * @stability stable
     */
    readonly configContext?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#config_context_auth_info HelmProvider#config_context_auth_info}.
     *
     * @stability stable
     */
    readonly configContextAuthInfo?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#config_context_cluster HelmProvider#config_context_cluster}.
     *
     * @stability stable
     */
    readonly configContextCluster?: string;
    /**
     * Path to the kube config file. Can be set with KUBE_CONFIG_PATH.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#config_path HelmProvider#config_path}
     *
     * @stability stable
     */
    readonly configPath?: string;
    /**
     * A list of paths to kube config files. Can be set with KUBE_CONFIG_PATHS environment variable.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#config_paths HelmProvider#config_paths}
     *
     * @stability stable
     */
    readonly configPaths?: string[];
    /**
     * The hostname (in form of URI) of Kubernetes master.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#host HelmProvider#host}
     *
     * @stability stable
     */
    readonly host?: string;
    /**
     * Whether server should be accessed without verifying the TLS certificate.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#insecure HelmProvider#insecure}
     *
     * @stability stable
     */
    readonly insecure?: boolean | cdktf.IResolvable;
    /**
     * The password to use for HTTP basic authentication when accessing the Kubernetes master endpoint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#password HelmProvider#password}
     *
     * @stability stable
     */
    readonly password?: string;
    /**
     * Token to authenticate an service account.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#token HelmProvider#token}
     *
     * @stability stable
     */
    readonly token?: string;
    /**
     * The username to use for HTTP basic authentication when accessing the Kubernetes master endpoint.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#username HelmProvider#username}
     *
     * @stability stable
     */
    readonly username?: string;
    /**
     * exec block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/helm#exec HelmProvider#exec}
     *
     * @stability stable
     */
    readonly exec?: HelmProviderKubernetesExec;
}
/**
 * @stability stable
 */
export declare class HelmProviderKubernetesOutputReference extends cdktf.ComplexObject {
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    private _clientCertificate?;
    /**
     * @stability stable
     */
    get clientCertificate(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set clientCertificate(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetClientCertificate(): void;
    /**
     * @stability stable
     */
    get clientCertificateInput(): string | undefined;
    private _clientKey?;
    /**
     * @stability stable
     */
    get clientKey(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set clientKey(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetClientKey(): void;
    /**
     * @stability stable
     */
    get clientKeyInput(): string | undefined;
    private _clusterCaCertificate?;
    /**
     * @stability stable
     */
    get clusterCaCertificate(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set clusterCaCertificate(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetClusterCaCertificate(): void;
    /**
     * @stability stable
     */
    get clusterCaCertificateInput(): string | undefined;
    private _configContext?;
    /**
     * @stability stable
     */
    get configContext(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set configContext(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetConfigContext(): void;
    /**
     * @stability stable
     */
    get configContextInput(): string | undefined;
    private _configContextAuthInfo?;
    /**
     * @stability stable
     */
    get configContextAuthInfo(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set configContextAuthInfo(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetConfigContextAuthInfo(): void;
    /**
     * @stability stable
     */
    get configContextAuthInfoInput(): string | undefined;
    private _configContextCluster?;
    /**
     * @stability stable
     */
    get configContextCluster(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set configContextCluster(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetConfigContextCluster(): void;
    /**
     * @stability stable
     */
    get configContextClusterInput(): string | undefined;
    private _configPath?;
    /**
     * @stability stable
     */
    get configPath(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set configPath(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetConfigPath(): void;
    /**
     * @stability stable
     */
    get configPathInput(): string | undefined;
    private _configPaths?;
    /**
     * @stability stable
     */
    get configPaths(): string[] | undefined | undefined;
    /**
     * @stability stable
     */
    set configPaths(value: string[] | undefined | undefined);
    /**
     * @stability stable
     */
    resetConfigPaths(): void;
    /**
     * @stability stable
     */
    get configPathsInput(): string[] | undefined;
    private _host?;
    /**
     * @stability stable
     */
    get host(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set host(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetHost(): void;
    /**
     * @stability stable
     */
    get hostInput(): string | undefined;
    private _insecure?;
    /**
     * @stability stable
     */
    get insecure(): boolean | cdktf.IResolvable | undefined | undefined;
    /**
     * @stability stable
     */
    set insecure(value: boolean | cdktf.IResolvable | undefined | undefined);
    /**
     * @stability stable
     */
    resetInsecure(): void;
    /**
     * @stability stable
     */
    get insecureInput(): boolean | cdktf.IResolvable | undefined;
    private _password?;
    /**
     * @stability stable
     */
    get password(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set password(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetPassword(): void;
    /**
     * @stability stable
     */
    get passwordInput(): string | undefined;
    private _token?;
    /**
     * @stability stable
     */
    get token(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set token(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetToken(): void;
    /**
     * @stability stable
     */
    get tokenInput(): string | undefined;
    private _username?;
    /**
     * @stability stable
     */
    get username(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set username(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetUsername(): void;
    /**
     * @stability stable
     */
    get usernameInput(): string | undefined;
    private _exec?;
    /**
     * @stability stable
     */
    get exec(): HelmProviderKubernetesExec | undefined | undefined;
    /**
     * @stability stable
     */
    set exec(value: HelmProviderKubernetesExec | undefined | undefined);
    /**
     * @stability stable
     */
    resetExec(): void;
    /**
     * @stability stable
     */
    get execInput(): HelmProviderKubernetesExec | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/helm helm}.
 *
 * @stability stable
 */
export declare class HelmProvider extends cdktf.TerraformProvider {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/helm helm} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: HelmProviderConfig);
    private _debug?;
    /**
     * @stability stable
     */
    get debug(): boolean | cdktf.IResolvable | undefined | undefined;
    /**
     * @stability stable
     */
    set debug(value: boolean | cdktf.IResolvable | undefined | undefined);
    /**
     * @stability stable
     */
    resetDebug(): void;
    /**
     * @stability stable
     */
    get debugInput(): boolean | cdktf.IResolvable | undefined;
    private _helmDriver?;
    /**
     * @stability stable
     */
    get helmDriver(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set helmDriver(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetHelmDriver(): void;
    /**
     * @stability stable
     */
    get helmDriverInput(): string | undefined;
    private _pluginsPath?;
    /**
     * @stability stable
     */
    get pluginsPath(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set pluginsPath(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetPluginsPath(): void;
    /**
     * @stability stable
     */
    get pluginsPathInput(): string | undefined;
    private _registryConfigPath?;
    /**
     * @stability stable
     */
    get registryConfigPath(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set registryConfigPath(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetRegistryConfigPath(): void;
    /**
     * @stability stable
     */
    get registryConfigPathInput(): string | undefined;
    private _repositoryCache?;
    /**
     * @stability stable
     */
    get repositoryCache(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set repositoryCache(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetRepositoryCache(): void;
    /**
     * @stability stable
     */
    get repositoryCacheInput(): string | undefined;
    private _repositoryConfigPath?;
    /**
     * @stability stable
     */
    get repositoryConfigPath(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set repositoryConfigPath(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetRepositoryConfigPath(): void;
    /**
     * @stability stable
     */
    get repositoryConfigPathInput(): string | undefined;
    private _alias?;
    /**
     * @stability stable
     */
    get alias(): string | undefined | undefined;
    /**
     * @stability stable
     */
    set alias(value: string | undefined | undefined);
    /**
     * @stability stable
     */
    resetAlias(): void;
    /**
     * @stability stable
     */
    get aliasInput(): string | undefined;
    private _experiments?;
    /**
     * @stability stable
     */
    get experiments(): HelmProviderExperiments | undefined | undefined;
    /**
     * @stability stable
     */
    set experiments(value: HelmProviderExperiments | undefined | undefined);
    /**
     * @stability stable
     */
    resetExperiments(): void;
    /**
     * @stability stable
     */
    get experimentsInput(): HelmProviderExperiments | undefined;
    private _kubernetes?;
    /**
     * @stability stable
     */
    get kubernetes(): HelmProviderKubernetes | undefined | undefined;
    /**
     * @stability stable
     */
    set kubernetes(value: HelmProviderKubernetes | undefined | undefined);
    /**
     * @stability stable
     */
    resetKubernetes(): void;
    /**
     * @stability stable
     */
    get kubernetesInput(): HelmProviderKubernetes | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
